==> haskell-tamarin-prover-term-1.2.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.2.3
id: tamarin-prover-term-1.2.3-AiYSm76tR4MKVx26fIlMp4
key: tamarin-prover-term-1.2.3-AiYSm76tR4MKVx26fIlMp4
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
abi: b02cc50fd02c88b0c174c5aeaf088111
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-term-1.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-term-1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-term-1.2.3
hs-libraries: HStamarin-prover-term-1.2.3-AiYSm76tR4MKVx26fIlMp4
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15 base-4.10.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    tamarin-prover-utils-1.2.3-LRaNfc8SJzb44WC7Bg29VZ
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             tamarin-prover-utils-1.2.3-LRaNfc8SJzb44WC7Bg29VZ=3906488fabaf470f4f56104ad1534323
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-term-1.4.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.4.0
id: tamarin-prover-term-1.4.0-4wrIa0WSIrfBkhpdG5N9l8
key: tamarin-prover-term-1.4.0-4wrIa0WSIrfBkhpdG5N9l8
license: GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
abi: 7bfd01ffb5415af6960755db642ff777
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-term-1.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-term-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-term-1.4.0
hs-libraries: HStamarin-prover-term-1.4.0-4wrIa0WSIrfBkhpdG5N9l8
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv base-4.10.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    tamarin-prover-utils-1.4.0-KAh5AYoM0Ce6frpfn5dHNP
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             tamarin-prover-utils-1.4.0-KAh5AYoM0Ce6frpfn5dHNP=9e0e3109dd02bbfe33e7c96802f8f79e
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
